@@ -46,8 +46,6 @@ class Pg:
 
     async def fetchs(self, **opt):
         "テーブルのデータを複数取得する"
-   
-       
         
         enums = enumerate(opt.keys(), 1)
         columns = ' AND '.join(f'{c} = ${i}' for i, c in enums)
@@ -56,12 +54,27 @@ class Pg:
         content = await self.pool.fetch(f"SELECT * FROM {self.table} WHERE {columns}", *opt.values())
  
         return content
-    
-    
-    async def limit_fetchs(self, guild: discord.Guild, limit, offset):
+
+    async def limit_fetchs(self, **opt):
         "テーブルのデータを制限数付きで取得する"
 
-        contents = await self.pool.fetch(f'select * from {self.table} where server =$1 limit $2 OFFSET $3', guild.id, limit, offset)
+        keys = list(opt.keys())
+        column = f"{keys[0]} = $1"
+        limit = f"{keys[1]} $2"
+        offset = f"{keys[2]} $3"
+
+        contents = await self.pool.fetch(f'SELECT * FROM {self.table} WHERE {column} {limit} {offset}', *opt.values())
+        return contents
+    
+
+
+    async def sort_fetchs(self, target, **opt):
+        "データをソートして取得"
+
+        column = f"{list(opt.keys())[0]} = $1"
+        limit = f"{list(opt.keys()[1])} $2"
+
+        contents = await self.pool.fetch(f'SELECT * FROM {self.table} WHERE {column} ODER BY {target} DESC {limit}', *opt.values())
         return contents
         
 
@@ -91,19 +104,7 @@ class Pg:
 
         await self.pool.execute(f"DELETE FROM {self.table} WHERE {' AND '.join(f'{c} = ${i}' for i, c in enums)}", *opt.values())
 
-    
-class Listpg:
-    """
-    bot - Bot
-    table - 対象のテーブル名
-    tableに配列型が存在するときのみこのクラスを使う
-    """
-    def __init__(self, bot, table:str):
-        self.bot=bot
-        self.pool=bot.pool
-        self.table=table
-            
-    
+
     async def add(self, **opt):
         one_column = f"{list(opt.keys())[0]} = array_append({list(opt.keys())[0]}, $1)"
         enums = enumerate(opt.keys(), 1)
